#!/usr/bin/bash
DATA_PATH=./data
interval=`expr 24 \* 3600`

function check_error {
if [[ $? -ne 0 ]]; then
    echo "Exiting with error . . ."
    exit $?
fi
}
echo "Sleeping for $1 seconds . . ."
sleep $1 2>/dev/null

while true
do
    echo "`date +%Y-%m-%d-%H-%M-%S` - top of the loop"
    start=`date +%s`
    end=`expr $start + $interval`

	while IFS='' read -r line || [[ -n "$line" ]]; do

		HOSTNAME=$(echo $line | cut -f1 -d,)
		DB2_INSTANCE=$(echo $line | cut -f2 -d,)
		DBNAME=$(echo $line | cut -f3 -d,)
		USERID=$(echo $line | cut -f4 -d,)
		PASSWORD=$(echo $line | cut -f5 -d,)
		FILE_DATE=`date +%s`
			
		db2ExecFileName=temp.`date +%Y-%m-%d-%H-%M-%S`.db2
		echo "connect to ${DBNAME} user ${USERID} using ${PASSWORD} ;" > $db2ExecFileName
		
		# Put a list of SYSIBMADM Views that you want to collect daily here
         SYSIBMADM_VIEWS="\
		    ADMINTABINFO \
            BP_HITRATIO \
            BP_READ_IO \
            BP_WRITE_IO \
            DB_HISTORY \
            DBCFG \
            DBMCFG \
            DBPATHS \
            ENV_INST_INFO \
            ENV_SYS_INFO \
            ENV_SYS_RESOURCES \
            MON_PKG_CACHE_SUMMARY \
            MON_BP_UTILIZATION \
            MON_CONNECTION_SUMMARY \
            MON_DB_SUMMARY \
            MON_LOCKWAITS \
            MON_SERVICE_SUBCLASS_SUMMARY \
            MON_TBSP_UTILIZATION \
            MON_WORKLOAD_SUMMARY \
            SNAPTAB_REORG \
            SNAPTBSP_RANGE \
            SNAPTBSP_QUIESCER \
            TBSP_UTILIZATION \
            SNAPTBSP \
            SNAPTBSP_PART \
            SNAPCONTAINER \
            CONTAINER_UTILIZATION \
            REG_VARIABLES \
            SNAPSTORAGE_PATHS\
            SNAPDYN_SQL \
            SNAPTAB \
            SNAPBP \
            SNAPDB_MEMORY_POOL \
            SNAPDBM \
            SNAPDBM_MEMORY_POOL"

		for SYSIBMADM_VIEW in $SYSIBMADM_VIEWS; do

			echo "export to ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.SYSIBMADM_${SYSIBMADM_VIEW}.ixf of ixf select * from sysibmadm.${SYSIBMADM_VIEW} with UR ;" >> $db2ExecFileName

		done
		
         SYSCAT_VIEWS="\
            DATAPARTITIONS \
            INDEXES \
            TABLES \
            VIEWDEP \
            BUFFERPOOLS \
			CONTEXTS \
            TABLESPACES"

		for SYSCAT_VIEW in $SYSCAT_VIEWS; do

			echo "export to ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.SYSCAT_${SYSCAT_VIEW}.ixf of ixf select * from syscat.${SYSCAT_VIEW} with UR ;" >> $db2ExecFileName

		done
		
		echo "connect reset;" >> $db2ExecFileName

		db2 -tvf $db2ExecFileName
		
		tar -cf ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.tar.progress ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.*.ixf 
		check_error

		gzip ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.tar.progress 
		check_error

		mv ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.tar.progress.gz ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.tar.gz
		check_error

		rm ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.*.ixf
		check_error
		
		mv ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.tar.gz ${DATA_PATH}

		rm $db2ExecFileName
		
	done < "DatabaseList.ini"

    now=`date +%s`

    sleepTime=`expr $end - $now`
    if (( $sleepTime < 0 )); then
        sleepTime=0
    fi

    echo sleep $sleepTime seconds
    sleep $sleepTime 
done