#!/usr/bin/bash
DATA_PATH=./data
interval=`expr 7 \* 24 \* 3600`

function check_error {
if [[ $? -ne 0 ]]; then
    echo "Exiting with error . . ."
    exit $?
fi
}
echo "Sleeping for $1 seconds . . ."
sleep $1 2>/dev/null

while true
do
    echo "`date +%Y-%m-%d-%H-%M-%S` - top of the loop"
    start=`date +%s`
    end=`expr $start + $interval`

	while IFS='' read -r line || [[ -n "$line" ]]; do

		HOSTNAME=$(echo $line | cut -f1 -d,)
		DB2_INSTANCE=$(echo $line | cut -f2 -d,)
		DBNAME=$(echo $line | cut -f3 -d,)
		USERID=$(echo $line | cut -f4 -d,)
		PASSWORD=$(echo $line | cut -f5 -d,)
		FILE_DATE=`date +%s`
			
		db2ExecFileName=temp.`date +%Y-%m-%d-%H-%M-%S`.db2
		echo "connect to ${DBNAME} user ${USERID} using ${PASSWORD} ;" > $db2ExecFileName
		
		# Put a list of SYSIBMADM Views that you want to collect hourly here
	
         SYSCAT_VIEWS="\
            DBPARTITIONGROUPDEF \
            DBPARTITIONGROUPS \
            DBAUTH \
            DATAPARTITIONS \
            TABAUTH \
            PACKAGEAUTH \
            PACKAGEDEP  \
            PACKAGES \ 
            TRIGGERS \
            NODEGROUPDEF \
            NODEGROUPS"
			
		for SYSCAT_VIEW in $SYSCAT_VIEWS; do

			echo "export to ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.SYSCAT_${SYSCAT_VIEW}.ixf of ixf select * from syscat.${SYSCAT_VIEW} with UR ;" >> $db2ExecFileName

		done

        echo "export to ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.SYSCAT_EVENTMONITORS.ixf of ixf select A.*, EVENT_MON_STATE(A.EVMONNAME) EVENT_MON_STATE from SYSCAT.EVENTMONITORS A ; ">> $db2ExecFileName

        echo "call REORGCHK_TB_STATS ('T', 'ALL') ;" >> $db2ExecFileName
		 
        echo "export to ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.REORGCHK_TB_STATS.ixf of ixf select * from session.tb_stats ;" >> $db2ExecFileName

        echo "call REORGCHK_IX_STATS ('T', 'ALL') ;" >> $db2ExecFileName
		 
        echo "export to ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.REORGCHK_IX_STATS.ixf of ixf select * from session.ix_stats ;" >> $db2ExecFileName

        echo "export to ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.MON_GET_INDEX.ixf of ixf select * from table(MON_GET_INDEX ('', '', -1)) as t ; " >> $db2ExecFileName
		
		echo "connect reset;" >> $db2ExecFileName

		db2 -tvf $db2ExecFileName
		
		tar -cf ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.tar.progress ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.*.ixf 
		check_error

		gzip ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.tar.progress 
		check_error

		mv ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.tar.progress.gz ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.tar.gz
		check_error

		rm ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.*.ixf
		check_error
		
		mv ${FILE_DATE}.${HOSTNAME}.${DB2_INSTANCE}.${DBNAME}.tar.gz ${DATA_PATH}

		rm $db2ExecFileName
		
	done < "DatabaseList.ini"

    now=`date +%s`

    sleepTime=`expr $end - $now`
    if (( $sleepTime < 0 )); then
        sleepTime=0
    fi

    echo sleep $sleepTime seconds
    sleep $sleepTime 
done